==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Graphics View</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kolory
&amp;Dodaj do własnych kolorów</translatorcomment>
        <translation type="unfinished">Kolory</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation type="unfinished">Graphics View</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Tło:
Tło rysunku:
Tło okna:</translatorcomment>
        <translation type="unfinished">Tło:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Krzyżyk:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Nieaktywne Krzyżyk:</translation>
    </message>
    <message>
        <location line="-562"/>
        <source>Origin:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pochodzenie:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Względna Zero:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Punkt odniesienia:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: designer_pl.ts--
&amp;Meta-siatka:
Meta-siatka:</translatorcomment>
        <translation type="unfinished">Siatka:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translatorcomment>--google--
&amp;Meta-siatka:
Meta-siatka:</translatorcomment>
        <translation type="obsolete">Siatka Meta:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Box Zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--</translatorcomment>
        <translation type="obsolete">Wybrane strony:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Border Box Selection:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Box Selection:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Krzyż pole wyboru:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pomocnicze Kształty:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tło Label Info:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Font Label Info:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Narzędzia pomiarowe:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Widok graficzny</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kolory
&amp;Dodaj do własnych kolorów</translatorcomment>
        <translation>Kolory</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Widok graficzny</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Tło:
Tło rysunku:
Tło okna:</translatorcomment>
        <translation>Tło:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Kursor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Krzyżyki:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Nieaktywne krzyżyki:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Początek układu współrzędnych</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Początek układu względnego:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Siatka</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta siatka:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Zaznaczenie</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Pierwszorzędny kolor zaznaczenia:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Użycie drugorzędnego koloru zaznaczenia</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Drugorzędny kolor zaznaczenia:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Przesuwane punkty odniesienia:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Drugorzędne punkty referencyjne:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Obramowanie prostokąta zaznaczenia:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Wypełnienie prostokąta zaznaczenia:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Wypełnienie prostokąta zaznaczenia krzyżowego:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>Punkty początkowe:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>Punkty końcowe:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Narzędzia przyciągania</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Etykieta przyciągania:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Narzędzia informacji</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Pomiary i etykiety:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Narzędzia rysowania</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Pomocnicze kształty:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Narzędzia przybliżania</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Obramowanie okna przybliżania:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Nieaktywne Krzyżyk:</translation>
    </message>
    <message>
        <location line="-616"/>
        <source>Origin:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Początek układu współrzędnych:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Względna Zero:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Punkt odniesienia:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: designer_pl.ts--
&amp;Meta-siatka:
Meta-siatka:</translatorcomment>
        <translation>Siatka:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translatorcomment>--google--
&amp;Meta-siatka:
Meta-siatka:</translatorcomment>
        <translation type="obsolete">Siatka Meta:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Box Zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--</translatorcomment>
        <translation type="obsolete">Wybrane strony:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Border Box Selection:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Box Selection:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Krzyż pole wyboru:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pomocnicze Kształty:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tło Label Info:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Font Label Info:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Narzędzia pomiarowe:</translation>
    </message>
</context>
</TS>
